@@ -101,7 +101,7 @@ class ResponseFrame:
         # Seperate the frame, every item is space seperated.
         items = frame.split(" ")
         if len(items) < 5:
-            return Err("Invalid frame contents, not enough items")
+            return Err(f"Invalid frame contents, not enough items: {items}")
         # example I2C: [i\w YXNkZmFzZGY= 4 Invalid 0]
         rf_type = ResponseFrameType.Standard
         if items[0].startswith("*"):
@@ -165,9 +165,9 @@ class ResponseFrame:
             data: bytes = bytes([int(x, 16) for x in response.split(" ")])
             return Ok(data)
         except TypeError as ex:
-            return Err(ex)
+            return Err(str(ex))
         except ValueError as ex:
-            return Err(ex)
+            return Err(str(ex))
 
     def timestamp_as_datetime(self, check_ok: bool = False) -> Result[np.datetime64, str]:
         """Convert the timestamp into a datetime.
