@@ -594,11 +594,14 @@ class FreeWiliSerial:
         # k) GUI Functions
         # l) Show FWI Image [pip_boy.fwi]
         self._empty_all()
-        cmd = f"g\nl\n{fwi_path}"
         if self.is_badge:
-            return Err("TODO")
-            cmd = "g\n" + cmd + "\nq\nq"
-        self.serial_port.send(cmd)
+            self.serial_port.send("g\ng", delay_sec=0.1)
+            self._handle_final_response_frame()
+            cmd = f"l\n{fwi_path}\nq\nq"
+            self.serial_port.send(cmd)
+        else:
+            cmd = f"g\nl\n{fwi_path}"
+            self.serial_port.send(cmd)
         return self._handle_final_response_frame()
 
     @needs_open()
@@ -619,9 +622,9 @@ class FreeWiliSerial:
         self._empty_all()
         cmd = "g\nt"
         if self.is_badge:
-            self.serial_port.send("g\ng")
+            self.serial_port.send("g\ng", delay_sec=0.0)
             self._handle_final_response_frame()
-            cmd = "g\nt\nq\nq"
+            cmd = "t\nq\nq"
             self.serial_port.send(cmd)
         else:
             cmd = "g\nt"
@@ -1399,17 +1402,23 @@ class FreeWiliSerial:
         resp = self._wait_for_response_frame()
         if resp.is_err():
             return Err(resp.err())
-        proc_type_regex = re.compile(r"(?:Main|Display)|(?:App version)|(?:\d+)")
+        proc_type_regex = re.compile(r"(?:Main|Display|DEFCON25|Winky|DEFCON24)|(?:App version)|(?:\d+)")
         results = proc_type_regex.findall(resp.unwrap().response)
         if len(results) != 2:
             return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Unknown, 0))
         # New firmware >= 48
         processor = results[0]
         version = results[1]
-        if "Main" in processor:
+        if "main" in processor.lower():
             return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Main, int(version)))
-        elif "Display" in processor:
+        elif "display" in processor.lower():
             return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Display, int(version)))
+        elif "winky" in processor.lower():
+            return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Main, int(version)))
+        elif "defcon24" in processor.lower():
+            return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Main, int(version)))
+        elif "defcon25" in processor.lower():
+            return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Main, int(version)))
         else:
             return Ok(FreeWiliAppInfo(FreeWiliProcessorType.Unknown, int(version)))
 
