@@ -54,7 +54,7 @@ class ButtonColor(enum.Enum):
     Red = enum.auto()
 
 
-class EventDataType(object):
+class EventData(object):
     """Base class for Free-Wili event data types."""
 
     @classmethod
@@ -80,7 +80,7 @@ class EventDataType(object):
 
 
 @dataclass(frozen=True)
-class Radio1Data(EventDataType):
+class Radio1Data(EventData):
     """Radio1 event data from Free-Wili Display."""
 
     # [*radio1 0DF6B2ADEAE711E2 4170 29 08 db 00 8e 90 ae e0 56 72 ... 1]
@@ -126,7 +126,7 @@ class UART1Data(Radio1Data):
 
 
 @dataclass(frozen=True)
-class GPIOData(EventDataType):
+class GPIOData(EventData):
     """GPIO event data from Free-Wili Display."""
 
     # [*gpioIn 0DF6B2ADB5DFB0B6 6 35873723 1]
@@ -161,7 +161,7 @@ class GPIOData(EventDataType):
 
 
 @dataclass(frozen=True)
-class AccelData(EventDataType):
+class AccelData(EventData):
     """Accelerometer event data from Free-Wili Display."""
 
     # [*accel 0DFEFB5DB4E34E9B 20 2g 64 -768 16448 29 84 4 1]
@@ -205,7 +205,7 @@ class AccelData(EventDataType):
 
 
 @dataclass(frozen=True)
-class ButtonData(EventDataType):
+class ButtonData(EventData):
     """Button event data from Free-Wili Display."""
 
     # [*button 0E027CA91437D2F5 7450 0 0 0 0 0 1]
@@ -241,7 +241,7 @@ class ButtonData(EventDataType):
 
 
 @dataclass(frozen=True)
-class IRData(EventDataType):
+class IRData(EventData):
     """IR event data from Free-Wili Display."""
 
     # [*irrx 0E02C19053D884DF 108 10008004 1]
@@ -272,7 +272,32 @@ class IRData(EventDataType):
 
 
 @dataclass(frozen=True)
-class RawData(EventDataType):
+class AudioData(EventData):
+    """Audio event data from Free-Wili Display."""
+
+    # [*audio 0E00CC80AEF767E4 6165 -956 -1192 -1296 -1276 -1268 -1260 -1136 -940 1]
+    data: list[int]
+
+    @classmethod
+    def from_string(cls, data: str) -> Self:
+        """Convert a string to an IRData object.
+
+        Arguments:
+        ----------
+            data: str
+                The string to convert, typically from an audio event.
+
+        Returns:
+        --------
+            AudioData:
+                The converted AudioData object.
+        """
+        data_int = [int(x) for x in data.split(" ")]
+        return cls(data=data_int)
+
+
+@dataclass(frozen=True)
+class RawData(EventData):
     """Raw event data from Free-Wili Display."""
 
     value: str
@@ -295,13 +320,16 @@ class RawData(EventDataType):
 
 
 @dataclass(frozen=True)
-class BatteryData(EventDataType):
+class BatteryData(EventData):
     """Battery event data from Free-Wili Display."""
 
     vbus: float
     vsys: float
-    ichg: float
+    vbatt: float
+    ichg: int
+    """Indicates if the battery is currently charging."""
     charging: bool
+    """True if the battery is charging, False otherwise."""
     charge_complete: bool
 
     @classmethod
@@ -322,21 +350,30 @@ class BatteryData(EventDataType):
         parts = data.split(" ")
         vbus = float(parts[0])
         vsys = float(parts[1])
-        ichg = float(parts[2])
-        if vbus < 1000 and vsys < 1000 and ichg < 1000:
+        vbatt = float(parts[2])
+        ichg = int(parts[3])
+        if vbus < 1000 and vsys < 1000 and vbatt < 1000:
             # v54 firmware looks like its math is off, so if everything is less than 1000, multiply by 10
             vbus *= 10.0
             vsys *= 10.0
-            ichg *= 10.0
+            vbatt *= 10.0
         return cls(
             vbus=vbus,
             vsys=vsys,
+            vbatt=vbatt,
             ichg=ichg,
-            charging=bool(int(parts[3])),
-            charge_complete=bool(int(parts[4])),
+            charging=bool(int(parts[4])),
+            charge_complete=bool(int(parts[5])),
         )
 
 
+# Type alias for all possible event data types
+# This allows us to use EventDataType in type hints and function signatures
+EventDataType = (
+    EventData | RawData | Radio1Data | Radio2Data | UART1Data | GPIOData | AccelData | ButtonData | IRData | BatteryData
+)
+
+
 class EventType(enum.Enum):
     """Free-Wili Event Type."""
 
@@ -350,11 +387,12 @@ class EventType(enum.Enum):
     Radio1 = enum.auto()
     Radio2 = enum.auto()
     UART1 = enum.auto()
+    Audio = enum.auto()
 
     def __str__(self) -> str:
         return self.name
 
-    def get_data_type(self) -> EventDataType:  # type: ignore[return-value]
+    def get_data_type(self) -> EventData:  # type: ignore[return-value]
         """Get the EventDataType class from this EventType.
 
         Arguments:
@@ -391,6 +429,8 @@ class EventType(enum.Enum):
                 return Radio2Data  # type: ignore[return-value]
             case self.UART1:
                 return UART1Data  # type: ignore[return-value]
+            case self.Audio:
+                return AudioData  # type: ignore[return-value]
             case _:
                 return RawData  # type: ignore[return-value]
 
@@ -432,6 +472,8 @@ class EventType(enum.Enum):
                 return cls(cls.Radio2)
             case "uart1":
                 return cls(cls.UART1)
+            case "audio":
+                return cls(cls.Audio)
             case _:
                 return cls(cls.Unknown)
 
@@ -527,3 +569,65 @@ class IOMenuCommand(enum.Enum):
             case self.Get:
                 return "u"
         raise ValueError(f"{self.name} ({self.value}) is not a supported menu command")
+
+
+class FileType(enum.Enum):
+    """Free-Wili File Type."""
+
+    Unknown = enum.auto()
+    Directory = enum.auto()
+    File = enum.auto()
+
+    def __str__(self) -> str:
+        return self.name
+
+    @classmethod
+    def from_string(cls, value: str) -> Self:
+        """Convert a string value to a FileType.
+
+        Arguments:
+        ----------
+            value: str
+                string value to convert to an enum. Case Insensitive.
+
+        Returns:
+        --------
+            FileType:
+                FreeWili file type.
+
+        """
+        match value.lower():
+            case "dir":
+                return cls(cls.Directory)
+            case "file":
+                return cls(cls.File)
+            case _:
+                return cls(cls.Unknown)
+
+
+@dataclass(frozen=True)
+class FileSystemItem:
+    """File system item representation for Free-Wili."""
+
+    """Name of the file system item."""
+    name: str
+    """Type of the file system item, either File or Directory."""
+    file_type: FileType
+    """Size of the file in bytes, 0 for directories."""
+    size: int = 0
+
+    def __str__(self) -> str:
+        return f"FileSystemItem(name={self.name}, file_type={self.file_type}, size={self.size})"
+
+
+@dataclass(frozen=True)
+class FileSystemContents:
+    """File system representation for Free-Wili."""
+
+    # File system current working directory
+    cwd: str
+    # List of files in the file system
+    contents: list[FileSystemItem]
+
+    def __str__(self) -> str:
+        return f"FileSystem(cwd={self.cwd}, contents={self.contents})"
